@@ -14,6 +14,8 @@
 #' @param n an integer. The number of occurrence points / records to sample.
 #' @param type \code{"presence only"} or \code{"presence-absence"}. The type of 
 #' occurrence points to sample.
+#' @param extract.probability \code{TRUE} or \code{FALSE}. If \code{TRUE}, then
+#' true probability at sampled locations will also be extracted
 #' @param sampling.area a character string, a \code{polygon} or an \code{extent}
 #' object.
 #' The area in which the sampling will take place. See details.
@@ -55,6 +57,11 @@
 #' @param plot \code{TRUE} or \code{FALSE}. If \code{TRUE}, the sampled 
 #' occurrence points will be plotted.
 #' @details
+#' \href{http://borisleroy.com/virtualspecies_tutorial/07-sampleoccurrences.html}{Online tutorial for this function}
+#' 
+#' 
+#' 
+#' 
 #' \bold{How the function works:}
 #' 
 #' The function randomly selects \code{n} cells in which samples occur. If a 
@@ -141,20 +148,22 @@
 #' biases along roads. In that case you have to provide to \code{weights} a 
 #' raster layer in which each cell contains the probability to be sampled.
 #' 
-#' #' The \code{\link{.Random.seed}} and \code{\link{RNGkind}} are stored as 
+#' The \code{\link{.Random.seed}} and \code{\link{RNGkind}} are stored as 
 #' \code{\link{attributes}} when the function is called, and can be used to 
 #' reproduce the results as shown in the examples (though
 #' it is preferable to set the seed with \code{\link{set.seed}} before calling
-#' \code{sampleRecords()} and to then use the same value in 
+#' \code{sampleOccurrences()} and to then use the same value in 
 #' \code{\link{set.seed}} to reproduce results later. Note that 
 #' reproducing the sampling will only work if the same original distribution map 
 #' is used.
 #' 
-#' @return a \code{list} with 7 elements:
+#' @return a \code{list} with 8 elements:
 #' \itemize{
-#' \item{\code{sample.points}: the data.frame containing the coordinates of 
-#' samples, the real presence-absences (or presence-only) and the sampled 
-#' presence-absences}
+#' \item{\code{type}: type of occurrence sampled (presence-absences or 
+#' presence-only)}
+#' \item{\code{sample.points}: data.frame containing the coordinates of 
+#' samples, true and sampled observations (i.e, 1, 0 or NA), and, if asked, the true
+#' environmental suitability in sampled locations}
 #' \item{\code{detection.probability}: the chosen probability of detection of
 #' the virtual species}
 #' \item{\code{error.probability}: the chosen probability to assign presence
@@ -270,6 +279,7 @@
 
 sampleOccurrences <- function(x, n,
                               type = "presence only",
+                              extract.probability = FALSE,
                               sampling.area = NULL,
                               detection.probability = 1,
                               correct.by.suitability = FALSE,
@@ -282,7 +292,8 @@ sampleOccurrences <- function(x, n,
                               replacement = FALSE,
                               plot = TRUE)
 {
-  results <- list(detection.probability = list(
+  results <- list(type = type,
+                  detection.probability = list(
                     detection.probability = detection.probability,
                     correct.by.suitability = correct.by.suitability),
                   error.probability = error.probability, 
@@ -309,6 +320,11 @@ sampleOccurrences <- function(x, n,
   } else if ("RasterLayer" %in% class(x))
   {
     sp.raster <- x
+    if(extract.probability)
+    {
+      stop("Cannot extract probability when x is not a virtualspecies object. Set
+           extract.probability = FALSE")
+    }
   } else stop("x must be:\n- a raster layer object\nor\n- the output list from 
               functions generateRandomSp(), convertToPA() or 
               limitDistribution()")
@@ -708,6 +724,13 @@ sampleOccurrences <- function(x, n,
     results$sample.plot <- grDevices::recordPlot()
   }
   
+  if(extract.probability)
+  {
+    sample.points <- data.frame(sample.points,
+                                true.probability = extract(x$probability.of.occurrence,
+                                                           sample.points[, c("x", "y")]))
+  }
+  
   
   results$sample.points <- sample.points
   if(type == "presence-absence")
